@@ -621,9 +621,12 @@ impl InternalParameters {
     fn parse_format_specific_params(format_specific_params: &str) -> Result<Self, String> {
         let mut sprop_parameter_sets = None;
         for p in format_specific_params.split(';') {
-            let (key, value) = p.trim().split_once('=').unwrap();
-            if key == "sprop-parameter-sets" {
-                sprop_parameter_sets = Some(value);
+            match p.trim().split_once('=') {
+                Some((key, value)) if key == "sprop-parameter-sets" => {
+                    sprop_parameter_sets = Some(value)
+                }
+                None => return Err("key without value".into()),
+                _ => (),
             }
         }
         let sprop_parameter_sets = sprop_parameter_sets
@@ -1341,13 +1344,34 @@ mod tests {
             payload: Bytes::from_static(b"\x65slice"),
         })
         .unwrap();
+
+        // By codec::Depacketizer::parameters's contract, it's unspecified what the depacketizer
+        // parameters are set to between push and pull.
+
         let frame = match d.pull() {
             Some(CodecItem::VideoFrame(frame)) => frame,
             o => panic!("unexpected pull result {:#?}", o),
         };
+
+        // After pull, new_parameters and parameters() both reflect the change.
         assert!(frame.new_parameters.is_some());
         let p = frame.new_parameters.unwrap();
         assert_eq!(p.pixel_dimensions(), (640, 480));
+        match d.parameters() {
+            Some(crate::codec::Parameters::Video(v)) => {
+                assert_eq!(v.pixel_dimensions(), (640, 480));
+            }
+            _ => unreachable!(),
+        }
+    }
+
+    /// Tests parsing empty parameters, which can for example happen with
+    /// v4l2-rtspserver if the hardware hasn't given it a frame with the required data yet.
+    /// (Mostly that it should not panic.)
+    #[test]
+    fn depacketize_empty() {
+        assert!(super::InternalParameters::parse_format_specific_params("").is_err());
+        assert!(super::InternalParameters::parse_format_specific_params(" ").is_err());
     }
 
     /// Tests parsing parameters from GW Security camera, which erroneously puts
